#include "Track.h"

#include <math.h>

Track::Track(){}
Track::~Track(){}

void Track::SetPtEtaPhiM(double pt,double eta,double phi,double m){
  if(m > 0) {
    px = pt*cos(phi);
    py = pt*sin(phi);
    double cosT = (exp(2*eta)-1)/(exp(2*eta)+1);
    pz = 0;
    if(fabs(cosT) != 1) pz = pt*cosT/sqrt(1-cosT*cosT); 
    e  = sqrt(px*px + py*py + pz*pz + m*m);
  }  
}

double Track::Px() const {return px;}
double Track::Py() const {return py;}
double Track::Pz() const {return pz;}
double Track::E() const {return e;}
double Track::M() const {return sqrt(e*e - (px*px + py*py + pz*pz));}
double Track::Pt() const {return sqrt(px*px + py*py);}
double Track::Eta() const {
  double p = sqrt(px*px + py*py + pz*pz);
  double cosT = 0;
  if(p > 0) cosT = pz/p;
  return 0.5*log((1+cosT)/(1-cosT));
}
double Track::Phi() const {
  double PI = 3.14159;
  double phi = PI/2;
  if(px != 0) phi = atan(py/px);
  if(px < 0)  phi += PI;
  if(px > 0 && py < 0) phi += 2*PI;
  return phi;
}

void Track::SetVertex(Vertex v){theVertex = v;}

Vertex Track::GetVertex() const { return theVertex; }

